﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using Syncfusion.XlsIO;
using System.ComponentModel;
using System.IO;

namespace EssentialXlsIOSamples
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class QuarterlySalesReport : Window
    {

        #region Members
        ExcelEngine excelEngine = null;
        IApplication application = null;
        IWorkbook workbook = null;
        IWorksheet worksheet = null;
        IChart chart = null;
        #endregion

        # region Constructor
        /// <summary>
        /// Window constructor
        /// </summary>
        public QuarterlySalesReport()
        {
            InitializeComponent();

            #region InitializeWorkbook
            //Step 1 : Instantiate the spreadsheet creation engine.
            excelEngine = new ExcelEngine();
            
            //Step 2 : Instantiate the excel application object.
            application = excelEngine.Excel;
            application.DefaultVersion = ExcelVersion.Excel2013;

            //A new workbook is created.[Equivalent to creating a new workbook in MS Excel]
            workbook = application.Workbooks.Open("../../Data/InputTemplate.xlsx", ExcelOpenType.Automatic);

            //The first worksheet object in the worksheets collection is accessed.
            worksheet = workbook.Worksheets[0];
            chart = worksheet.Charts[0];
            #endregion

            #region InitializeListboxes
            //Adding series names in the series list box
            for (int i = 0; i < chart.Series.Count; i++)
            {
                CheckBox chkBox = new CheckBox();
                chkBox.Content = chart.Series[i].Name.ToString();
                chkBox.IsChecked = true;
                lstSeries.Items.Add(chkBox);
            }

            //Adding categories name in the categories list box
            for (int i = 0; i < 4; i++)
            {
                CheckBox chkBox = new CheckBox();
                chkBox.Content = chart.Categories[i].Name.ToString();
                chkBox.IsChecked = true;
                lstCategories.Items.Add(chkBox);
            }
            #endregion
        }
        # endregion

        /// <summary>
        /// Creates spreadsheet
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCreate_Click(object sender, RoutedEventArgs e)
        {
            #region Applying Filter
            //Applying series filter
            for (int i = 0; i < lstSeries.Items.Count; i++)
            {
                CheckBox chkBox = lstSeries.Items[i] as CheckBox;
                chart.Series[chkBox.Content.ToString()].IsFiltered = (bool)!chkBox.IsChecked;
            }

            //Applying categories filter
            for (int i = 0; i < lstCategories.Items.Count; i++)
            {
                CheckBox chkBox = lstCategories.Items[i] as CheckBox;
                chart.Categories[chkBox.Content.ToString()].IsFiltered = (bool)!chkBox.IsChecked;
            }
            #endregion

            #region Saving the workbook
            //Saving the workbook
            string fileName = "../../Output/Report.xlsx";
            workbook.Version = ExcelVersion.Excel2013;
            workbook.SaveAs(fileName);
            #endregion

            #region Workbook Close and Dispose
            //Close the workbook.
            workbook.Close();
            excelEngine.Dispose();
            #endregion

            #region View the Workbook
            //Message box confirmation to view the created spreadsheet.
            if (MessageBox.Show("Do you want to view the workbook?", "Workbook has been created",
                MessageBoxButton.YesNo, MessageBoxImage.Information) == MessageBoxResult.Yes)
            {
                try
                {
                    //Launching the Excel file using the default Application.[MS Excel Or Free ExcelViewer]
                    System.Diagnostics.Process.Start(Path.GetFullPath(fileName));

                    //Exit
                    this.Close();
                }
                catch (Win32Exception ex)
                {
                    MessageBox.Show("MS Excel is not installed in this system");
                    Console.WriteLine(ex.ToString());
                }
            }
            else
                // Exit
                this.Close();
            #endregion
        }
    }
}